@@ -3,10 +3,18 @@
  */
 package org.gcube.portlets.user.td.openwidget.client;
 
+
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TableData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.open.TDOpenSession;
+import org.gcube.portlets.user.td.openwidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.event.RibbonEvent;
+import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.RibbonType;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -27,24 +35,23 @@ import com.sencha.gxt.widget.core.client.event.HideEvent.HideHandler;
  * 
  */
 public class TabResourcesSelectionCard extends WizardCard {
-	protected final String GRIDWIDTH = "538px";
-	protected final String GRIDHEIGHT = "430px";
 
 	protected TabResourcesSelectionCard thisCard;
+	protected TRId trId;
 	protected TDOpenSession tdOpenSession;
 	protected TabResourcesSelectionPanel tabResourcesSelectionPanel;
 	protected TabResource selectedTabResource = null;
 
-	public TabResourcesSelectionCard(final TDOpenSession tdOpenSession) {
+	public TabResourcesSelectionCard(TRId trId,
+			final TDOpenSession tdOpenSession) {
 		super("Select a Tabular Resource", "");
 		Log.debug("TabResourcesSelectionCard");
 		this.tdOpenSession = tdOpenSession;
 		thisCard = this;
+		this.trId = trId;
 
-		tabResourcesSelectionPanel = new TabResourcesSelectionPanel(thisCard,res);
-
-		// tabResourcesSelectionPanel.setResize(false);
-		// tabResourcesSelectionPanel.setSize(GRIDWIDTH, GRIDHEIGHT);
+		tabResourcesSelectionPanel = new TabResourcesSelectionPanel(thisCard,
+				res);
 
 		tabResourcesSelectionPanel
 				.addSelectionHandler(new SelectionHandler<TabResource>() {
@@ -84,19 +91,26 @@ public class TabResourcesSelectionCard extends WizardCard {
 
 					@Override
 					public void onFailure(Throwable caught) {
-						Log.debug("Attention",
-								"This tabular resource does not have a valid table");
-						AlertMessageBox d = new AlertMessageBox("Attention",
-								"This tabular resource does not have a valid table");
-						d.addHideHandler(new HideHandler() {
+						if (caught instanceof TDGWTSessionExpiredException) {
+							getEventBus()
+									.fireEvent(
+											new SessionExpiredEvent(
+													SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							Log.debug("Attention",
+									"This tabular resource does not have a valid table");
+							AlertMessageBox d = new AlertMessageBox(
+									"Attention",
+									"This tabular resource does not have a valid table");
+							d.addHideHandler(new HideHandler() {
 
-							public void onHide(HideEvent event) {
-								deleteTRWithLastTableNull();
-
-							}
-						});
-						d.show();
+								public void onHide(HideEvent event) {
+									deleteTRWithLastTableNull();
 
+								}
+							});
+							d.show();
+						}
 					}
 
 					@Override
@@ -127,36 +141,47 @@ public class TabResourcesSelectionCard extends WizardCard {
 		mb.show();
 
 	}
-	
-	protected void callDeleteLastTable(){
-		Log.debug("Delete TR:" + tdOpenSession
-				.getSelectedTabResource().getTrId());
+
+	protected void callDeleteLastTable() {
+		Log.debug("Call Delete TR:"
+				+ tdOpenSession.getSelectedTabResource().getTrId());
 		TDGWTServiceAsync.INSTANCE.removeTabularResource(tdOpenSession
-				.getSelectedTabResource().getTrId(),
-				new AsyncCallback<Void>() {
+				.getSelectedTabResource().getTrId(), new AsyncCallback<Void>() {
 
-					public void onFailure(Throwable caught) {
-						AlertMessageBox d = new AlertMessageBox("Error",
-								"Error on delete TabResource: "
-										+ caught.getLocalizedMessage());
-						d.addHideHandler(new HideHandler() {
+			public void onFailure(Throwable caught) {
+				if (caught instanceof TDGWTSessionExpiredException) {
+					getEventBus()
+							.fireEvent(
+									new SessionExpiredEvent(
+											SessionExpiredType.EXPIREDONSERVER));
+				} else {
+					Log.error("Error on delete TabResource: "
+							+ caught.getLocalizedMessage());
+					UtilsGXT3.alert("Error",
+							"Error on delete TabResource: "
+									+ caught.getLocalizedMessage());
+				}
 
-							public void onHide(HideEvent event) {
-								// TODO Auto-generated method stub
+			}
 
-							}
-						});
-						d.show();
-						
-					}
+			public void onSuccess(Void result) {
+				Log.debug("Remove tabular resource success");
+				Log.debug("Check current tr for close: " + trId);
+				if (trId != null
+						&& trId.getId() != null
+						&& trId.getId().compareTo(
+								tdOpenSession.getSelectedTabResource()
+										.getTrId().getId()) == 0) {
+					Log.debug("Fire Close Event on current TR");
+					getEventBus().fireEvent(new RibbonEvent(RibbonType.CLOSE));
+				} else {
+					Log.debug("No tr opened");
+				}
+				tabResourcesSelectionPanel.gridReload();
+			}
 
-					public void onSuccess(Void result) {
-						tabResourcesSelectionPanel.gridReload();
-					}
-
-				});
+		});
 	}
-	
 
 	protected void updateTDOpenSessionInfo(TableData table) {
 		TabResource tabResource = tdOpenSession.getSelectedTabResource();
@@ -171,18 +196,18 @@ public class TabResourcesSelectionCard extends WizardCard {
 				tdOpenSession.getSelectedTabResource(),
 				new AsyncCallback<Void>() {
 					public void onFailure(Throwable caught) {
-						AlertMessageBox d = new AlertMessageBox("Error",
-								"Error on set TabResource: "
-										+ caught.getLocalizedMessage());
-						d.addHideHandler(new HideHandler() {
-
-							public void onHide(HideEvent event) {
-								// TODO Auto-generated method stub
-
-							}
-
-						});
-						d.show();
+						if (caught instanceof TDGWTSessionExpiredException) {
+							getEventBus()
+									.fireEvent(
+											new SessionExpiredEvent(
+													SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							Log.error("Error on set TabResource: "
+									+ caught.getLocalizedMessage());
+							UtilsGXT3.alert("Error",
+									"Error on set TabResource: "
+											+ caught.getLocalizedMessage());
+						}
 
 					}
 
